#!/usr/bin/env node

'use strict';

const pkg = require(`../package.json`);
var program = require(`commander`);
var semanticRelease = require(`./index.js`);

program
  .description(pkg.description)
  .version(pkg.version)
  .option(`-p, --preset <convention>`, `Preset package name [angular, @scope/angular, ...]. See 'conventional-recommended-bump' for preset package requirements.`)
  .option(`-d, --dryrun`, `Calculate the next release flag but don't perform the git tag or release.`)
  .parse(process.argv);
const packageOpts = {
  preset: program.preset,
  dryrun: program.dryrun
};

semanticRelease(packageOpts)
  .then(function (releasedVersion) {
	  let message="";
	if(packageOpts.dryrun) {
		message = releasedVersion ? releasedVersion: oldTag;
	} else {
		 message = releasedVersion ?
			`Released version ${releasedVersion}` :
			`No changes are available to release.`;
	}
    console.log(message);
  })
  .catch(error => {
    console.error(`semantic-release-gitlab failed for the following reason - ${error}`);
    process.exit(1);
  });

